@@ -2,13 +2,13 @@
 
 __author__ = """Luis C. Berrocal"""
 __email__ = 'luis.berrocal.1942@gmail.com'
-__version__ = '1.2.0'
+__version__ = '1.2.3'
 
 from rich.console import Console
 
 from environment_backups.config.configuration import ConfigurationManager
 
-CONFIGURATION_MANAGER = ConfigurationManager()
+CONFIGURATION_MANAGER = ConfigurationManager(version=__version__)
 
 CONSOLE = Console()
 
