@@ -13,9 +13,10 @@ class ConfigurationManager:
     DEFAULT_CONFIG_FILENAME = 'configuration.toml'
     APP_NAME = DEFAULT_CONFIG_FOLDER_NAME[1:].replace('_', '-')
 
-    def __init__(self, config_root_folder: Optional[Path] = None, config_filename: Optional[str] = None):
+    def __init__(self, config_root_folder: Optional[Path] = None, config_filename: Optional[str] = None,
+                 version: str = None):
         # TODO Add version to init for use in backups
-
+        self.version = version
         if config_root_folder is None:
             self.config_folder = Path().home() / self.DEFAULT_CONFIG_FOLDER_NAME
         else:
@@ -67,7 +68,9 @@ class ConfigurationManager:
     def backup(self) -> Path:
         if self.config_file.exists():
             # TODO Add version number
-            backup_filename = backup_file(self.config_file, self.config_backup_folder)
+            backup_filename = backup_file(filename=self.config_file,
+                                          backup_folder=self.config_backup_folder,
+                                          current_version=self.version)
             return backup_filename
 
     def delete(self) -> Path:
@@ -90,7 +93,7 @@ def get_configuration_by_name(
     """Get the configuration based on a name.
     @param config_name: Name of the configuration.
     @param app_configuration: Application configuration.
-    @return: Tuple with configuration and fuzzy probabilliy
+    @return: Tuple with configuration and fuzzy probability
     """
     # TODO Implement thefuzz for fuzzy search
     config = None
